==> moodle-2.3.11.zip: moodle/lang/en/debug.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'debug', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   debug
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['authpluginnotfound'] = 'Authentication plugin {$a} not found.';
$string['blocknotexist'] = '{$a} block doesn\'t exist';
$string['cannotbenull'] = '{$a} cannot be null!';
$string['cannotdowngrade'] = 'Cannot downgrade {$a->plugin} from {$a->oldversion} to {$a->newversion}.';
$string['cannotfindadmin'] = 'Could not find an admin user!';
$string['cannotinitpage'] = 'Cannot fully initialize page: invalid {$a->name} id {$a->id}';
$string['cannotsetuptable'] = '{$a} tables could NOT be set up successfully!';
$string['codingerror'] = 'Coding error detected, it must be fixed by a programmer: {$a}';
$string['configmoodle'] = 'Moodle has not been configured yet. You need to edit config.php first.';
$string['erroroccur'] = 'An error has occurred during this process';
$string['invalidarraysize'] = 'Incorrect size of arrays in params of {$a}';
$string['invalideventdata'] = 'Incorrect eventadata submitted: {$a}';
$string['invalidparameter'] = 'Invalid parameter value detected';
$string['invalidresponse'] = 'Invalid response value detected';
$string['missingconfigversion'] = 'Config table does not contain version, can not continue, sorry.';
$string['modulenotexist'] = '{$a} module doesn\'t exist';
$string['morethanonerecordinfetch'] = 'Found more than one record in fetch() !';
$string['mustbeoveride'] = 'Abstract {$a} method must be overridden.';
$string['noactivityname'] = 'Page object derived from page_generic_activity but did not define $this->activityname';
$string['noadminrole'] = 'No admin role could be found';
$string['noblocks'] = 'No blocks installed!';
$string['nocate'] = 'No categories!';
$string['nomodules'] = 'No modules found!!';
$string['nopageclass'] = 'Imported {$a} but found no page classes';
$string['noreports'] = 'No reports accessible';
$string['notables'] = 'No tables!';
$string['phpvaroff'] = 'The PHP server variable \'{$a->name}\' should be Off - {$a->link}';
$string['phpvaron'] = 'The PHP server variable \'{$a->name}\' is not turned On - {$a->link}';
$string['sessionmissing'] = '{$a} object missing from session';
$string['sqlrelyonobsoletetable'] = 'This SQL relies on obsolete table(s): {$a}!  Your code must be fixed by a developer.';
$string['withoutversion'] = 'Main version.php file is missing, not readable or broken.';
$string['xmlizeunavailable'] = 'xmlize functions are not available';

==> moodle-3.10.11.zip: moodle/lang/en/debug.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'debug', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   core
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['authpluginnotfound'] = 'Authentication plugin {$a} not found.';
$string['blocknotexist'] = '{$a} block doesn\'t exist';
$string['cannotbenull'] = '{$a} cannot be null!';
$string['cannotdowngrade'] = 'Cannot downgrade {$a->plugin} from {$a->oldversion} to {$a->newversion}.';
$string['cannotfindadmin'] = 'Could not find an admin user!';
$string['cannotinitpage'] = 'Cannot fully initialize page: invalid {$a->name} id {$a->id}';
$string['cannotsetuptable'] = '{$a} tables could NOT be set up successfully!';
$string['codingerror'] = 'Coding error detected, it must be fixed by a programmer: {$a}';
$string['configmoodle'] = 'Moodle has not been configured yet. You need to edit config.php first.';
$string['debuginfo'] = 'Debug info';
$string['erroroccur'] = 'An error has occurred during this process';
$string['invalidarraysize'] = 'Incorrect size of arrays in params of {$a}';
$string['invalideventdata'] = 'Incorrect event data submitted: {$a}';
$string['invalidparameter'] = 'Invalid parameter value detected';
$string['invalidresponse'] = 'Invalid response value detected';
$string['line'] = 'Line';
$string['missingconfigversion'] = 'Config table does not contain the version. You cannot continue.';
$string['modulenotexist'] = '{$a} module doesn\'t exist';
$string['morethanonerecordinfetch'] = 'Found more than one record in fetch() !';
$string['mustbeoveride'] = 'Abstract {$a} method must be overridden.';
$string['noadminrole'] = 'No admin role could be found';
$string['noblocks'] = 'No blocks installed!';
$string['nocate'] = 'No categories!';
$string['nomodules'] = 'No modules found!!';
$string['nopageclass'] = 'Imported {$a} but found no page classes';
$string['noreports'] = 'No reports accessible';
$string['notables'] = 'No tables!';
$string['outputbuffer'] = 'Output buffer';
$string['phpvaroff'] = 'The PHP server variable \'{$a->name}\' should be Off - {$a->link}';
$string['phpvaron'] = 'The PHP server variable \'{$a->name}\' is not turned On - {$a->link}';
$string['sessionmissing'] = '{$a} object missing from session';
$string['sqlrelyonobsoletetable'] = 'This SQL relies on obsolete table(s): {$a}!  Your code must be fixed by a developer.';
$string['stacktrace'] = 'Stack trace';
$string['withoutversion'] = 'Main version.php file is missing, not readable or broken.';
$string['xmlizeunavailable'] = 'xmlize functions are not available';
